**Example 1: 申请黑石EIP**



Input: 

```
tccli bmeip CreateEip --cli-unfold-argument  \
    --VpcId vpc-bjh0qd20
```

Output: 
```
{
    "Response": {
        "EipIds": [
            "eip-k5zjz4yy"
        ],
        "TaskId": 2488124,
        "RequestId": "b2c6a502-66f1-4101-a40a-387ac764f09e"
    }
}
```

